@@ -1,21 +1,21 @@
-class DisallowedPath(BaseException):
+class DisallowedPath(Exception):
     """
     The path is not allowed by the robots.txt.
     """
 
 
-class ParsingError(BaseException):
-    """
-    An error occurred while parsing the page.
-    """
-
-
-class Unauthorized(BaseException):
+class Unauthorized(Exception):
     """
     The user is not logged-in.
     """
 
 
+class ParsingError(Exception):
+    """
+    An error occurred while parsing the page.
+    """
+
+
 class NonePage(ParsingError):
     """
     The parsed page is None.
@@ -28,6 +28,12 @@ class NoTitle(ParsingError):
     """
 
 
+class NotFound(ParsingError):
+    """
+    The resource could not be found.
+    """
+
+
 class DisabledAccount(ParsingError):
     """
     The resource belongs to a disabled account.
